SELECT cust_first_name, cust_last_name, credit_limit
  FROM customers
 WHERE LOWER(cust_last_name) = 'bogart'
/

-- A composite index on (cust_first_name, cust_last_name)
-- will NOT be used:
-- 1. The WHERE clause applies a function, LOWER, to the CUST_LAST_NAME.
-- 2. Were the function absent, the index would still not be used unless
--    CUST_LAST_NAME is the leading column of the composite index.

-- To determine if your index is being used, you can:
-- a. Examine the execution plan for your query, using either:
--    - EXPLAIN PLAN
--    - (SQL*Plus) SET AUTOTRACE ON EXPLAIN
-- b. Enable monitoring for the index:
--      ALTER INDEX index_name MONITORING USAGE
--    - After running the query, examine V$OBJECT_USAGE to see if
--      the USED field is 'YES' for your index.

SET AUTOTRACE ON EXPLAIN

SELECT cust_first_name, cust_last_name, credit_limit
  FROM customers
 WHERE LOWER(cust_last_name) = 'bogart'
/

SET AUTOTRACE OFF EXPLAIN

ALTER INDEX customer_fullname MONITORING USAGE
/

SELECT index_name, monitoring, used
  FROM v$object_usage
/

SELECT cust_first_name, cust_last_name, credit_limit
  FROM customers
 WHERE LOWER(cust_last_name) = 'bogart'
/

SELECT index_name, monitoring, used FROM v$object_usage
/

SELECT cust_first_name, cust_last_name, credit_limit
  FROM customers
 WHERE cust_first_name = 'Bob'
/

SELECT index_name, monitoring, used FROM v$object_usage
/

ALTER INDEX customer_fullname NOMONITORING USAGE
/
